@@ -331,6 +331,14 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isIgnorePhpunitDeprecations());
     }
 
+    public function test_Can_be_filtered_for_IgnorePhpunitWarnings(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isIgnorePhpunitWarnings();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isIgnorePhpunitWarnings());
+    }
+
     public function test_Can_be_filtered_for_PostCondition(): void
     {
         $collection = $this->collectionWithOneOfEach()->isPostCondition();
@@ -475,6 +483,14 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isTestDox());
     }
 
+    public function test_Can_be_filtered_for_TestDoxFormatter(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isTestDoxFormatter();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isTestDoxFormatter());
+    }
+
     public function test_Can_be_filtered_for_Test(): void
     {
         $collection = $this->collectionWithOneOfEach()->isTest();
@@ -583,6 +599,7 @@ final class MetadataCollectionTest extends TestCase
                 Metadata::groupOnClass(''),
                 Metadata::ignoreDeprecationsOnClass(),
                 Metadata::ignorePhpunitDeprecationsOnClass(),
+                Metadata::ignorePhpunitWarnings(null),
                 Metadata::postCondition(0),
                 Metadata::preCondition(0),
                 Metadata::preserveGlobalStateOnClass(true),
@@ -610,6 +627,7 @@ final class MetadataCollectionTest extends TestCase
                 Metadata::runInSeparateProcess(),
                 Metadata::runTestsInSeparateProcesses(),
                 Metadata::testDoxOnClass(''),
+                Metadata::testDoxFormatter('', ''),
                 Metadata::test(),
                 Metadata::testWith([]),
                 Metadata::usesNamespace(''),
